"""
  Dave Skura, 2023
"""
import sys

from postgresdave_package.postgresdave import postgres_db #install pip install postgresdave-package

def main():
	if len(sys.argv) == 1 or sys.argv[1] == 'postgres_extract.py': # no parameters
		print('usage: ')
		print('postgres_extract.py [query] [csvfilename] [delimiter] ') 
		print('')

	elif (len(sys.argv) == 2) : 
		query = sys.argv[1]
		myexp = dbexport(query)

	elif (len(sys.argv) == 3) : 
		query = sys.argv[1]
		csv_filename = sys.argv[2]
		myexp = dbexport(query,csv_filename)

	elif (len(sys.argv) == 4) : 
		query = sys.argv[1]
		csv_filename = sys.argv[2]
		delimiter = sys.argv[3]
		myexp = dbexport(query,csv_filename,delimiter)

	else:
		print('Error: Incorrect number of parameters.')
		print('')
		print('usage: ')
		print('postgres_extract.py [query] [csvfilename] [delimiter] ') 
		print('')

class dbexport():
	def __init__(self,query='',csv_filename='',delimiter='\t'):
		self.mydb = postgres_db()
		if csv_filename == '':
			csv_filename='query.tsv'

		self.mydb.export_query_to_csv(query,csv_filename,delimiter)
		self.mydb.close()

		print('query exported to ' + csv_filename)


if __name__ == '__main__':
	main()

		




"""
  Dave Skura
  
"""
from sqlitedave_package.sqlitedave import sqlite_db


class var:
	def __init__(self):
		self.db=sqlite_db()

	def set_global_variable(self,variable_name,variable_value):
		dsql = "DELETE FROM z_global WHERE name ='" + variable_name + "'"
		isql = "INSERT INTO z_global(name,value) VALUES ('" + variable_name + "','" + variable_value + "')"
		try:
			self.db.execute(dsql)
		except:
			print('z_global does not exist, creating it')
			self.create_var_table()

		self.db.execute(isql)

	def get_global_variable(self,variable_name):
		sql = "SELECT value FROM z_global WHERE name ='" + variable_name + "'"
		try:
			value = self.db.queryone(sql)
		except:
			print('z_global does not exist, creating it')
			self.create_var_table()
			value = self.db.queryone(sql)
		return value

	def create_var_table(self):
		csql = """
		CREATE TABLE z_global (
			name text PRIMARY KEY,
			value text
		);
		"""
		self.db.execute(csql)
